
package Bundle::DBD::Pg;

use strict;
use warnings;
use 5.008001;

our $VERSION = '3.20.1';

1;

__END__

=head1 NAME

Bundle::DBD::Pg - A bundle to install all DBD::Pg related modules

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::DBD::Pg'>

=head1 CONTENTS

DBI

DBD::Pg

=head1 DESCRIPTION

This bundle includes all the modules needed for DBD::Pg (the Perl 
interface to the Postgres database system). Please feel free to 
ask for help or report any problems to dbd-pg@perl.org.

=cut

=head1 AUTHOR

Greg Sabino Mullane E<lt>F<greg@turnstep.com>E<gt>

=cut

